# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .vellum_audio import VellumAudio


class TestCaseAudioVariableValue(UniversalBaseModel):
    """
    An audio value for a variable in a Test Case.
    """

    variable_id: str
    name: typing.Optional[str] = None
    type: typing.Literal["AUDIO"] = "AUDIO"
    value: typing.Optional[VellumAudio] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .vellum_image import VellumImage


class ExecutionImageVellumValue(UniversalBaseModel):
    """
    A base Vellum primitive value representing an image.
    """

    id: str = pydantic.Field()
    """
    The variable's uniquely identifying internal id.
    """

    name: str
    type: typing.Literal["IMAGE"] = "IMAGE"
    value: typing.Optional[VellumImage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



from abc import ABC, abstractmethod
import importlib.abc


class BaseWorkflowFinder(importlib.abc.MetaPathFinder, ABC):
    """
    Abstract base class for workflow finders that support custom error message formatting.
    """

    @abstractmethod
    def format_error_message(self, error_message: str) -> str:
        """
        Format an error message to be more user-friendly.

        Args:
            error_message: The original error message

        Returns:
            The formatted error message
        """
        pass
